@@ -36,6 +36,8 @@ import imp
 import html.parser
 import hashlib
 
+from enum import Enum
+
 from .util import TrackSubClasses
 
 logger = logging.getLogger(__name__)
@@ -78,6 +80,7 @@ class FilterBase(object, metaclass=TrackSubClasses):
 
     @classmethod
     def process(cls, filter_kind, subfilter, state, data):
+        logger.info('Applying filter %r, subfilter %r to %s', filter_kind, subfilter, state.job.get_location())
         filtercls = cls.__subclasses__.get(filter_kind, None)
         if filtercls is None:
             raise ValueError('Unknown filter kind: %s:%s' % (filter_kind, subfilter))
@@ -155,11 +158,18 @@ class Html2TextFilter(FilterBase):
     __kind__ = 'html2text'
 
     def filter(self, data, subfilter=None):
-        if subfilter is None:
-            subfilter = 're'
 
+        if subfilter is None:
+            method = 're'
+            options = {}
+        elif isinstance(subfilter, dict):
+            method = subfilter.pop('method')
+            options = subfilter
+        elif isinstance(subfilter, str):
+            method = subfilter
+            options = {}
         from .html2txt import html2text
-        return html2text(data, method=subfilter)
+        return html2text(data, method=method, options=options)
 
 
 class Ical2TextFilter(FilterBase):
@@ -209,14 +219,24 @@ class StripFilter(FilterBase):
         return data.strip()
 
 
-class ElementsByAttribute(html.parser.HTMLParser):
-    def __init__(self, name, value):
+class FilterBy(Enum):
+    ATTRIBUTE = 1
+    TAG = 2
+
+
+class ElementsBy(html.parser.HTMLParser):
+    def __init__(self, filter_by, name, value=None):
         super().__init__()
 
-        self._attributes = {name: value}
+        self._filter_by = filter_by
+        if self._filter_by == FilterBy.ATTRIBUTE:
+            self._attributes = {name: value}
+        else:
+            self._name = name
+
         self._result = []
         self._inside = False
-        self._depth = 0
+        self._elts = []
 
     def get_html(self):
         return ''.join(self._result)
@@ -224,19 +244,24 @@ class ElementsByAttribute(html.parser.HTMLParser):
     def handle_starttag(self, tag, attrs):
         ad = dict(attrs)
 
-        if all(ad.get(k, None) == v for k, v in self._attributes.items()):
+        if self._filter_by == FilterBy.ATTRIBUTE and all(ad.get(k, None) == v for k, v in self._attributes.items()):
+            self._inside = True
+        elif self._filter_by == FilterBy.TAG and tag == self._name:
             self._inside = True
 
         if self._inside:
             self._result.append('<%s%s%s>' % (tag, ' ' if attrs else '',
                                               ' '.join('%s="%s"' % (k, v) for k, v in attrs)))
-            self._depth += 1
+            self._elts.append(tag)
 
     def handle_endtag(self, tag):
         if self._inside:
             self._result.append('</%s>' % (tag,))
-            self._depth -= 1
-            if self._depth == 0:
+            if tag in self._elts:
+                t = self._elts.pop()
+                while t != tag and self._elts:
+                    t = self._elts.pop()
+            if not self._elts:
                 self._inside = False
 
     def handle_data(self, data):
@@ -253,7 +278,7 @@ class GetElementById(FilterBase):
         if subfilter is None:
             raise ValueError('Need an element ID for filtering')
 
-        element_by_id = ElementsByAttribute('id', subfilter)
+        element_by_id = ElementsBy(FilterBy.ATTRIBUTE, 'id', subfilter)
         element_by_id.feed(data)
         return element_by_id.get_html()
 
@@ -267,11 +292,39 @@ class GetElementByClass(FilterBase):
         if subfilter is None:
             raise ValueError('Need an element class for filtering')
 
-        element_by_class = ElementsByAttribute('class', subfilter)
+        element_by_class = ElementsBy(FilterBy.ATTRIBUTE, 'class', subfilter)
         element_by_class.feed(data)
         return element_by_class.get_html()
 
 
+class GetElementByStyle(FilterBase):
+    """Get all HTML elements by style"""
+
+    __kind__ = 'element-by-style'
+
+    def filter(self, data, subfilter=None):
+        if subfilter is None:
+            raise ValueError('Need an element style for filtering')
+
+        element_by_style = ElementsBy(FilterBy.ATTRIBUTE, 'style', subfilter)
+        element_by_style.feed(data)
+        return element_by_style.get_html()
+
+
+class GetElementByTag(FilterBase):
+    """Get an HTML element by its tag"""
+
+    __kind__ = 'element-by-tag'
+
+    def filter(self, data, subfilter=None):
+        if subfilter is None:
+            raise ValueError('Need a tag for filtering')
+
+        element_by_tag = ElementsBy(FilterBy.TAG, subfilter)
+        element_by_tag.feed(data)
+        return element_by_tag.get_html()
+
+
 class Sha1Filter(FilterBase):
     """Calculate the SHA-1 checksum of the content"""
 
