@@ -206,7 +206,7 @@ class HtmlReporter(ReporterBase):
                 '</pre>',
             ))
         else:
-            raise ValueError('Diff style not supported: %r', cfg['diff'])
+            raise ValueError('Diff style not supported: %r' % (difftype,))
 
 
 class TextReporter(ReporterBase):
@@ -343,7 +343,11 @@ class EMailReporter(TextReporter):
             logger.debug('Not sending e-mail (no changes)')
             return
         if self.config['method'] == "smtp":
-            mailer = SMTPMailer(self.config['smtp']['host'], self.config['smtp']['port'],
+            if self.config['smtp']['user']:
+                self.smtp_user = self.config['smtp']['user']
+            else:
+                self.smtp_user = self.config['from']
+            mailer = SMTPMailer(self.smtp_user, self.config['smtp']['host'], self.config['smtp']['port'],
                                 self.config['smtp']['starttls'], self.config['smtp']['keyring'])
         elif self.config['method'] == "sendmail":
             mailer = SendmailMailer(self.config['sendmail']['path'])
@@ -383,7 +387,7 @@ class WebServiceReporter(TextReporter):
 
         try:
             service = self.web_service_get()
-        except:
+        except Exception as e:
             logger.error('Failed to load or connect to %s - are the dependencies installed and configured?',
                          self.__kind__, exc_info=True)
             return
@@ -466,3 +470,49 @@ class MailGunReporter(TextReporter):
                                                                                                result.content))
 
         return result
+
+
+class TelegramReporter(TextReporter):
+    """Custom Telegram reporter"""
+    MAX_LENGTH = 4096
+
+    __kind__ = 'telegram'
+
+    def submit(self):
+
+        bot_token = self.config['bot_token']
+        chat_id = self.config['chat_id']
+
+        text = '\n'.join(super().submit())
+
+        if not text:
+            logger.debug('Not calling telegram API (no changes)')
+            return
+
+        result = None
+
+        for chunk in self.chunkstring(text, self.MAX_LENGTH):
+            result = self.submitToTelegram(bot_token, chat_id, chunk)
+
+        return result
+
+    def submitToTelegram(self, bot_token, chat_id, text):
+        logger.debug("Sending telegram request to chat id:'{0}'".format(chat_id))
+        result = requests.post(
+            "https://api.telegram.org/bot{0}/sendMessage".format(bot_token),
+            data={"chat_id": chat_id, "text": text, "disable_web_page_preview": "true"})
+        try:
+            json_res = result.json()
+
+            if (result.status_code == 200):
+                logger.info("Telegram response: ok '{0}'. {1}".format(json_res['ok'], json_res['result']))
+            else:
+                logger.error("Telegram error: {0}".format(json_res['description']))
+        except ValueError:
+            logger.error(
+                "Failed to parse telegram response. HTTP status code: {0}, content: {1}".format(result.status_code,
+                                                                                                result.content))
+        return result
+
+    def chunkstring(self, string, length):
+        return (string[0 + i:length + i] for i in range(0, len(string), length))
